import subprocess


def main():
    """Run the lora train script."""
    # Call the shell command
    command = [
        "docker",
        "exec",
        "-it",
        "rb-lora",
        "lora_pti",
        "--pretrained_model_name_or_path=runwayml/stable-diffusion-v1-5",
        "--instance_data_dir=/home/engineering/data",
        "--output_dir=/home/engineering/output",
        "--train_text_encoder",
        "--resolution=512",
        "--train_batch_size=1",
        "--gradient_accumulation_steps=4",
        "--scale_lr",
        "--learning_rate_unet=1e-4",
        "--learning_rate_text=1e-5",
        "--learning_rate_ti=5e-4",
        "--color_jitter",
        "--lr_scheduler=linear",
        "--lr_warmup_steps=0",
        '--placeholder_tokens="<s1>|<s2>"',
        '--use_template="style"',
        "--save_steps=100",
        "--max_train_steps_ti=1000",
        "--max_train_steps_tuning=1000",
        "--perform_inversion=True",
        "--clip_ti_decay",
        "--weight_decay_ti=0.000",
        "--weight_decay_lora=0.001",
        "--continue_inversion",
        "--continue_inversion_lr=1e-4",
        '--device="cuda:0"',
        "--lora_rank=1",
    ]

    subprocess.call(command)


if __name__ == "__main__":
    main()



import os
import subprocess
import sys

import requests


def main():
    """Run the webui script."""

    script_dir = os.path.dirname(os.path.realpath(__file__))
    ckpt_path = os.path.join(script_dir, "sd-v1-4-full-ema.ckpt")
    if not os.path.isfile(ckpt_path):
        url = "https://huggingface.co/CompVis/stable-diffusion-v-1-4-original/resolve/main/sd-v1-4-full-ema.ckpt"
        response = requests.get(url)
        if response.status_code == 200:
            with open(ckpt_path, "wb") as f:
                f.write(response.content)
        else:
            print(f"Failed to download checkpoint file. Status code: {response.status_code}")
            sys.exit(1)

    if "rb-sd-webui" in subprocess.check_output(["docker", "ps", "-a"]).decode("utf-8"):
        subprocess.call(["docker", "stop", "rb-sd-webui"])
        subprocess.call(["docker", "rm", "rb-sd-webui"])

    subprocess.call(
        [
            "docker",
            "run",
            "--name",
            "rb-sd-webui",
            "--gpus",
            "all",
            "-it",
            "-d",
            "-v",
            os.path.join(script_dir, "sd-v1-4-full-ema.ckpt")
            + ":/home/engineering/stable-diffusion-webui/models/Stable-diffusion/sd-v1-4-full-ema.ckpt",
            "-d",
            "rubbrband/sd-webui:latest",
        ]
    )

    subprocess.call(
        [
            "docker",
            "exec",
            "-it",
            "rb-sd-webui",
            "/bin/bash",
            "-c",
            "bash webui.sh --xformers --share --enable-insecure-extension-access",
        ]
    )


if __name__ == "__main__":
    main()
